@@ -49,7 +49,6 @@
 
 package com.openexchange.mobilepush.json;
 
-import com.openexchange.documentation.annotations.Module;
 import com.openexchange.server.ServiceLookup;
 
 
@@ -58,7 +57,6 @@ import com.openexchange.server.ServiceLookup;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-@Module(name = "pushregistry", description = "Provides access to mobile notifier module.")
 public final class AliasMobilePushActionFactory extends MobilePushActionFactory {
 
     /**
