@@ -54,10 +54,10 @@ import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
-import com.openexchange.documentation.annotations.Module;
 import com.openexchange.exception.OXException;
 import com.openexchange.mobilepush.json.actions.AbstractMobilePushAction;
 import com.openexchange.mobilepush.json.actions.PublicInfoAction;
+import com.openexchange.mobilepush.json.actions.ResetAction;
 import com.openexchange.mobilepush.json.actions.SubscribeAction;
 import com.openexchange.mobilepush.json.actions.UnsubscribeAction;
 import com.openexchange.mobilepush.json.actions.UpdateAction;
@@ -68,7 +68,6 @@ import com.openexchange.server.ServiceLookup;
  *
  * @author <a href="mailto:lars.hoogestraat@open-xchange.com">Lars Hoogestraat</a>
  */
-@Module(name = "mobilenotifier", description = "Provides access to mobile notifier module.")
 public class MobilePushActionFactory implements AJAXActionServiceFactory {
 
     private final Map<String, AbstractMobilePushAction> actions;
@@ -83,6 +82,7 @@ public class MobilePushActionFactory implements AJAXActionServiceFactory {
         actions.put("unsubscribe", new UnsubscribeAction(serviceLookup));
         actions.put("updateToken", new UpdateAction(serviceLookup));
         actions.put("publicInfo", new PublicInfoAction(serviceLookup));
+        actions.put("reset", new ResetAction(serviceLookup));
     }
 
     @Override
