@@ -122,4 +122,14 @@ public interface MobilePushStorageService {
      * @return a list of subscription
      */
     List<Subscription> getSubscriptions(int contextId, int userId, String serviceId, MobilePushProvider provider) throws OXException;
+
+    /**
+     * Resets all existing subscriptions
+     *
+     * @param session The associated session
+     * @param serviceId The serviceId of the push service e.g. <ul><li>gcm</li><li>apn</li><li>apn.macos</li></ul>
+     * @param provider The provider
+     * @throws OXException If reset attempt fails
+     */
+    void resetSubscriptions(Session session, String serviceId, MobilePushProvider provider) throws OXException;
 }
