@@ -60,6 +60,7 @@ import java.util.List;
 import java.util.Set;
 import com.openexchange.context.ContextService;
 import com.openexchange.database.DatabaseService;
+import com.openexchange.database.Databases;
 import com.openexchange.exception.OXException;
 import com.openexchange.mobilepush.MobilePushExceptionCodes;
 import com.openexchange.mobilepush.MobilePushProvider;
@@ -121,6 +122,36 @@ public class RdbMobilePushStorageImpl implements MobilePushStorageService {
         }
     }
 
+    @Override
+    public void resetSubscriptions(Session session, String serviceId, MobilePushProvider provider) throws OXException {
+        Connection connection = databaseService.getWritable(session.getContextId());
+        boolean modified = false;
+        try {
+            modified = resetSubscriptions(session, serviceId, provider, connection);
+        } finally {
+            if (modified) {
+                databaseService.backWritable(session.getContextId(), connection);
+            } else {
+                databaseService.backWritableAfterReading(session.getContextId(), connection);
+            }
+        }
+    }
+
+    private boolean resetSubscriptions(Session session, String serviceId, MobilePushProvider provider, Connection connection) throws OXException {
+        PreparedStatement stmt = null;
+        try {
+            stmt = connection.prepareStatement("DELETE FROM mobileEventSubscriptions WHERE cid=? AND service=? AND provider=?");
+            stmt.setInt(1, session.getContextId());
+            stmt.setString(2, serviceId);
+            stmt.setString(3, provider.getProviderName());
+            return stmt.executeUpdate() > 0;
+        } catch (SQLException e) {
+            throw MobilePushExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+        } finally {
+            Databases.closeSQLStuff(stmt);
+        }
+    }
+
     @Override
     public boolean updateToken(int contextId, String token, String serviceId, String newToken) throws OXException {
         Connection connection = databaseService.getWritable(contextId);
