@@ -72,7 +72,7 @@ public interface MobilePushEventService {
     /**
      * Notifies subscribers with a valid session about the triggered event.
      *
-     * @param publisher
+     * @param event
      */
-    void notifySubscribers(MobilePushEvent publisher);
+    void notifySubscribers(MobilePushEvent event);
 }
